@@ -10,7 +10,7 @@ import uuid
 import traceback
 
 
-def delay_task(task_name, **kwargs):
+def delay_task(task_name, *args, **kwargs):
     """Delay a task for execution by the ``celery`` daemon.
 
     Examples
@@ -22,8 +22,8 @@ def delay_task(task_name, **kwargs):
         raise tasks.NotRegistered(
                 "Task with name %s not registered in the task registry." % (
                     task_name))
-    publisher = TaskPublisher(connection=DjangoAMQPConnection)
-    task_id = publisher.delay_task(task_name, **kwargs)
+    publisher = TaskPublisher(connection=DjangoAMQPConnection())
+    task_id = publisher.delay_task(task_name, *args, **kwargs)
     publisher.close()
     return task_id
 
@@ -37,7 +37,7 @@ def discard_all():
     Returns the number of tasks discarded.
 
     """
-    consumer = TaskConsumer(connection=DjangoAMQPConnection)
+    consumer = TaskConsumer(connection=DjangoAMQPConnection())
     discarded_count = consumer.discard_all()
     consumer.close()
     return discarded_count
@@ -80,8 +80,8 @@ class Task(object):
     All subclasses of ``Task`` has to define the ``name`` attribute, which is
     the name of the task that can be passed to ``celery.task.delay_task``,
     it also has to define the ``run`` method, which is the actual method the
-    ``celery`` daemon executes. This method does not support positional
-    arguments, only keyword arguments.
+    ``celery`` daemon executes.
+    
 
     Examples
     --------
@@ -116,11 +116,11 @@ class Task(object):
         if not self.name:
             raise NotImplementedError("Tasks must define a name attribute.")
 
-    def __call__(self, **kwargs):
+    def __call__(self, *args, **kwargs):
         """The ``__call__`` is called when you do ``Task().run()`` and calls
         the ``run`` method. It also catches any exceptions and logs them."""
         try:
-            retval = self.run(**kwargs)
+            retval = self.run(*args, **kwargs)
         except Exception, e:
             logger = self.get_logger(**kwargs)
             logger.critical("Task got exception %s: %s\n%s" % (
@@ -129,7 +129,7 @@ class Task(object):
         else:
             return retval
 
-    def run(self, **kwargs):
+    def run(self, *args, **kwargs):
         """The actual task. All subclasses of :class:`Task` must define
         the run method, if not a ``NotImplementedError`` exception is raised.
         """
@@ -141,16 +141,16 @@ class Task(object):
 
     def get_publisher(self):
         """Get a celery task message publisher."""
-        return TaskPublisher(connection=DjangoAMQPConnection)
+        return TaskPublisher(connection=DjangoAMQPConnection())
 
     def get_consumer(self):
         """Get a celery task message consumer."""
-        return TaskConsumer(connection=DjangoAMQPConnection)
+        return TaskConsumer(connection=DjangoAMQPConnection())
 
     @classmethod
-    def delay(cls, **kwargs):
+    def delay(cls, *args, **kwargs):
         """Delay this task for execution by the ``celery`` daemon(s)."""
-        return delay_task(cls.name, **kwargs)
+        return delay_task(cls.name, *args, **kwargs)
 
 
 class TaskSet(object):
@@ -204,11 +204,12 @@ class TaskSet(object):
             True
         """
         taskset_id = str(uuid.uuid4())
-        publisher = TaskPublisher(connection=DjangoAMQPConnection)
+        publisher = TaskPublisher(connection=DjangoAMQPConnection())
         subtask_ids = []
         for arg in self.arguments:
             subtask_id = publisher.delay_task_in_set(task_name=self.task_name,
                                                      taskset_id=taskset_id,
+                                                     task_args=[],
                                                      task_kwargs=arg)
             subtask_ids.append(subtask_id) 
         publisher.close()
@@ -254,16 +255,6 @@ class PeriodicTask(Task):
         super(PeriodicTask, self).__init__()
 
 
-class TestTask(Task):
-    """A simple test task that just logs something."""
-    name = "celery.test_task"
-
-    def run(self, some_arg, **kwargs):
-        logger = self.get_logger(**kwargs)
-        logger.info("TestTask got some_arg=%s" % some_arg)
-tasks.register(TestTask)
-
-
 class DeleteExpiredTaskMetaTask(PeriodicTask):
     """A periodic task that deletes expired task metadata every day.
    
